@@ -44,7 +44,7 @@ SOME FEATURES OF RP:
 		ans, PREV, UNDO, etc
 		Tons of pretty themes
 	COOL THINGS TO NOTICE:
-		Invariant to prompt_toolkit version. This should run anywhere fine.
+		Invariant to prompt_toolkit version. This should run anywhere fine. (Todo: Make it have 0 dependencies)
 		rp includes a lot of tools made by different people. But the thing is, mine works out-of-the-box, no setup required. It makes these tools easy and accessible, as simple as 'pip install rp'.
 
 KEY KEY:
@@ -106,42 +106,59 @@ MICROCOMPLETIONS:
 
 	BACKSLASH COMMANDS:
 		WITH ARGUMENTS:
-			\sa  save file       (used like ‹`file.py\sa›. Saves the current buffer to 'file.py'. Will create a backup file if we overwrite something.)
-			\wr  write file      (used like ‹`file.py\wr›. Saves the current buffer to 'file.py'. Not as safe as save file, because it will not create a backup file when overwriting.)
-			\lo  load file       (used like ‹`file.py\lo›. Loads 'file.py' into the current buffer)
-			\re  replace         (used like ‹`old`new\re›. It's a search-and-replace)
-			\py  python          (used like ‹`repr\py›, or ‹`print_fix\py› etc. Replaces current buffer's text with function(currenttext))
-			\go  goto            (used like ‹`10\go›. Bring the cursor to that line number.)
-			\dtl delete to line  (used like ‹`5\dtl›. Like d5G in vim.)
-			\ca  cancel          (cancels any command you would have written and deletes the arguments. More civilized than spamming undo or backspace.)
+			\sa   save file       (used like ‹`file.py\sa›. Saves the current buffer to 'file.py'. Will create a backup file if we overwrite something.)
+			\wr   write file      (used like ‹`file.py\wr›. Saves the current buffer to 'file.py'. Not as safe as save file, because it will not create a backup file when overwriting.)
+			\lo   load file       (used like ‹`file.py\lo›. Loads 'file.py' into the current buffer)
+			\re   replace         (used like ‹`old`new\re›. It's a search-and-replace)
+			\py   python          (used like ‹`repr\py›, ‹`str.upper\py›, or ‹`print_fix\py› etc. Replaces current buffer's text with function(currenttext))
+			\go   goto            (used like ‹`10\go›. Bring the cursor to that line number.)
+			\dtl  delete to line  (used like ‹`5\dtl›. Like d5G in vim.)
+			\ca   cancel          (cancels any command you would have written and deletes the arguments. More civilized than spamming undo or backspace.)
 		WITHOUT ARGUMENTS:
-			\db  debugger                (toggles the existence of 'debug()' on the top of your prompt without moving your cursor)
-			\pu  pudb (other debugger)   (similar to \de, pudb is an alternative debugger, and this command also toggles a line on the top of the buffer. Whether you use this or \de is a matter of prefernece.)
-			\vi  vim                     (opens up the current buffer in vim. Edit your code, then save the temp file and close vim. Your cursor's position will be shared between vim and rp.)
-			\ed  editor                  (opens up the current buffer in some text editor; might be nano, might be vim. Depends on what you have. This command is an alternative to \vi)
-			\ac  align char              (inserts ‹→›, aka the alignment character. Used before \al. See https://asciinema.org/a/KjFS2lT0shRyv4r82RtFENzlo)
-			\al  align                   (aligns all alignment characters to the same column. Used after inserting \ac in multiple different places.)
-			\co  copy                    (copies the current buffer to your clipboard)
-			\pa  paste                   (equivalent to control+v)
-			\spa string paste            (pastes current clipboard as a python string literal)
-			\da  delete all              (deletes all text in the current buffer)
-			\sw  strip whitespace        (strips all trailing whitespace in the buffer)
-			\sc  strip comments          (removes all #comments in the buffer)
-			\d0l delete empty lines      (removes empty lines in the buffer. d0l means there can be 0 consecutive empty lines)
-			\rl  reverse lines           (reversed the order of all lines of text in the buffer)
-			\sl  sort lines              (sorts all lines in the buffer in alphabetical order)
-			\ya  yapf autoformatter      (autoformats your current code buffer using google's yapf library)
-			\fn  function name           (writes the name of the current function)
-			\gg  go to top               (like gg in vim. bring cursor to the top of the buffer)
-			\GG  go to bottom            (like G in vim. bring cursor to the bottom of the buffer)
-			\vO  insert line above       (like O in vim. Inserts a new line above the current line.)
-			\vo  insert line below       (like o in vim. Inserts a new line below the current line.)
-			\mla multi line arguments    (turns a lengthy def into a multi line def. See https://asciinema.org/a/RHuWRKsbwvkH3P28XZ81MnFYJ)
-			\tbp toggle big parenthesis  (enables/disables using big parenthesis on a given line https://asciinema.org/a/jhxmIcRogKp4yJy1gojIZBAem)
-			\tts tabs to spaces          (turns all tabs in the buffer into 4 spaces)
-			\23p python 2 to 3           (converts python2 code to python3 code: "print raw_input('>>>')") --> "print(input('>>>'))")
-			\fo  for-loopify             (envelops the whole buffer into a for loop. Useful for when you have a command but just want to run it over without DITTO, which pollutes HISTORY)
-			\wh  while-loopify           (envelops the whole buffer into a 'while True' loop. Useful for when you have a command but just want to loop it indefinitely
+			\lo   load file               (loads a file just like `file.py\lo does, except it opens a dialog to let you choose the file so you dont have to type it manually)
+			\db   debugger                (toggles the existence of 'debug()' on the top of your prompt without moving your cursor)
+			\pu   pudb (other debugger)   (similar to \db, pudb is an alternative debugger, and this command also toggles a line on the top of the buffer. Whether you use this or \db is a matter of prefernece.)
+			\vi   vim                     (opens up the current buffer in vim. Edit your code, then save the temp file and close vim. Your cursor's position will be shared between vim and rp.)
+			\ed   editor                  (opens up the current buffer in some text editor; might be nano, might be vim. Depends on what you have. This command is an alternative to \vi)
+			\ac   align char              (inserts ‹→›, aka the alignment character. Used before \al. See https://asciinema.org/a/KjFS2lT0shRyv4r82RtFENzlo)
+			\al   align                   (aligns all alignment characters to the same column. Used after inserting \ac in multiple different places.)
+			\co   copy                    (copies the current buffer to your clipboard)
+			\pa   paste                   (equivalent to control+v)
+			\spa  string paste            (pastes current clipboard as a python string literal)
+			\wco  web copy                (applies WCOPY to the current buffer's string. Use this to copy text between computers)
+			\wpa  web paste               (inserts the output of WPASTE at your cursor position. Use this to paste text from another computer.)
+			\wspa web string paste        (inserts the output of repr(WPASTE) at your cursor position. Use this to paste text from another computer.)
+			\lco  local copy              (same as \wco  except it uses LCOPY  instead of WCOPY )
+			\lpa  local paste             (same as \wpa  except it uses LPASTE instead of WPASTE)
+			\lspa local string paste      (same as \wspa except it uses LCOPY  instead of WCOPY )
+			\tco  tmux copy               (applies TCOPY to the current buffer's string. Use this to copy text to a tmux session)
+			\tpa  tmux paste              (inserts the output of TPASTE at your cursor position. Use this to paste text from a tmux session. This is useful because often tmux will press the enter key when pasting a multiline string.)
+			\tspa tmux string paste       (inserts the output of repr(TPASTE) at your cursor position. Use this to paste text from a tmux session. This is useful because often tmux will press the enter key when pasting a multiline string.)
+			\an   ans                     (inserts  str(ans) at current cursor position)
+			\sa   string ans              (inserts repr(ans) at current cursor position)
+			\da   delete all              (deletes all text in the current buffer)
+			\sw   strip whitespace        (strips all trailing whitespace in the buffer)
+			\sc   strip comments          (removes all #comments in the buffer)
+			\d0l  delete empty lines      (removes empty lines in the buffer. d0l means there can be 0 consecutive empty lines)
+			\rl   reverse lines           (reversed the order of all lines of text in the buffer)
+			\sl   sort lines              (sorts all lines in the buffer in alphabetical order)
+			\ya   yapf autoformatter      (autoformats your current code buffer using google's yapf library)
+			\fn   function name           (writes the name of the current function)
+			\gg   go to top               (like gg in vim. bring cursor to the top of the buffer)
+			\GG   go to bottom            (like G in vim. bring cursor to the bottom of the buffer)
+			\vO   insert line above       (like O in vim. Inserts a new line above the current line.)
+			\vo   insert line below       (like o in vim. Inserts a new line below the current line.)
+			\mla  multi line arguments    (turns a lengthy def into a multi line def. See https://asciinema.org/a/RHuWRKsbwvkH3P28XZ81MnFYJ)
+			\tbp  toggle big parenthesis  (enables/disables using big parenthesis on a given line https://asciinema.org/a/jhxmIcRogKp4yJy1gojIZBAem)
+			\tts  tabs to spaces          (turns all tabs in the buffer into 4 spaces)
+			\23p  python 2 to 3           (converts python2 code to python3 code: "print raw_input('>>>')") --> "print(input('>>>'))")
+			\fo   for-loopify             (envelops the whole buffer into a for loop. Useful for when you have a command but just want to run it over without DITTO, which pollutes HISTORY)
+			\wh   while-loopify           (envelops the whole buffer into a 'while True' loop. Useful for when you have a command but just want to loop it indefinitely)
+			\de   functionify             (envelops the whole buffer into a function body)
+			\lss  LS SEL                  (lets you select a file or folder and inserts the absolute path as a string)
+			\lsr  (Relative) LS SEL       (lets you select a file or folder and inserts the relative path as a string)
+			\rpr  repr                    (is equivalent to `repr\py  It will turn your buffer into a string literal)
+			\rpa  repr to ans             (sets ans to the current buffer's text)
 
 	FOR LOOPS:
 		COMPREHENSION:
@@ -319,6 +336,8 @@ MICROCOMPLETIONS:
 	MISC:
 		''''. –––>  ''.join(|)
 		;\n –––> new line
+		On ?:  print(x[thing¦]) –––> print(x[thing])?¦   //Don't have to move cursor to use inspection ?'s
+		On \n: ans[5/¦] –––> ans[5]?\n¦
 		On ‹-›: ‹def func(x,y,z)¦:›  –––>  ‹def func(x,y,z)->¦:›     // - goes to -> in functions
 		On ‹-›: ‹def func(x,y,z)->¦:›  –––>  ‹def func(x,y,z)->¦:›   // nothing happens
 		On ‹>›: ‹def func(x,y,z)->¦:›  –––>  ‹def func(x,y,z)->¦:›   // nothing happens
