@@ -363,11 +363,14 @@ class PythonCompleter(Completer):
             # ric.current_candidates==ric.current_candidates[::-1]
 
         for x in ric.current_candidates:
-            if not x.startswith('_'):#Make sure things starting with '_' come last...
+            if not x.startswith('_') and not x.startswith('.'):#Make sure things starting with '_' come last...
                 yield Completion(text=x,start_position=-len(post_period_origin),display=x)
         for x in ric.current_candidates:
             if     x.startswith('_'):
                 yield Completion(text=x,start_position=-len(post_period_origin),display=x)
+        for x in ric.current_candidates:
+            if     x.startswith('.'): #Private files, such as .backup_.py should be displayed last
+                yield Completion(text=x,start_position=-len(post_period_origin),display=x)
         # print("TIME2:",end='')
         # ptoc()
         # print()
@@ -455,4 +458,4 @@ def ryan_completion_matches(origin:str,candidates:list):
     # rp.ptoc()
     _ryan_completion_matches_cache[h]=out
     return out
- 
\ No newline at end of file
+ 
