@@ -315,6 +315,10 @@ def status_bar(python_input):
     def toggle_microcompletions(cli, mouse_event):
         python_input.enable_microcompletions = not python_input.enable_microcompletions
 
+    @if_mousedown
+    def toggle_wrap_lines(cli, mouse_event):
+        python_input.wrap_lines = not python_input.wrap_lines
+
     @if_mousedown
     def toggle_paste_mode(cli, mouse_event):
         python_input.paste_mode = not python_input.paste_mode
@@ -364,13 +368,29 @@ def status_bar(python_input):
             else:
                 append((TB, 'Mouse:Off ', toggle_mouse_support))
 
+            
+
             result.extend([
-                (TB.Key, '[F7]', toggle_microcompletions),
+                (TB.Key, '[F7]', toggle_wrap_lines),
+            ])
+            if hasattr(python_input,'wrap_lines') and python_input.wrap_lines:
+                append((TB, 'Wrap:On  ', toggle_wrap_lines))
+            else:
+                append((TB.PasteModeOn, 'Wrap:Off ', toggle_wrap_lines))
+
+
+
+            result.extend([
+                (TB.Key, '[F8]', toggle_microcompletions),
             ])
             if hasattr(python_input,'enable_microcompletions') and python_input.enable_microcompletions:
                 append((TB, 'Micro:On  ', toggle_microcompletions))
             else:
                 append((TB.PasteModeOn, 'Micro:Off ', toggle_microcompletions))
+            
+
+
+
         #region RYAN BURGERT CODE GOES HERE FOR PSEUDOTERMINAL STUFF
         if hasattr(python_input,'show_last_assignable') and python_input.show_last_assignable:
             append((TB, ' '))
